<?php
/**
 * Menu widgets
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Check if WooCommerce is active.
if ( !is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
	return;
}

class RestaurantPro_Widget_Menu extends Widget_Base {

	public function get_name() {
		return 'restaurantpro-menu';
	}

	public function get_title() {
		return esc_html__( 'Menu', 'restaurantpro' );
	}

	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	public function get_keywords() {
		return [ 'shop', 'product', 'menu' ];
	}

	public function get_categories() {
		return [ 'tj_extras_elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_product',
			[
				'label' => esc_html__( 'Product', 'restaurantpro' ),
			]
		);

		$this->add_control(
			'count',
			[
				'label'         => esc_html__( 'Product Per Page', 'restaurantpro' ),
				'description'   => esc_html__( 'You can enter "-1" to display all items.', 'restaurantpro' ),
				'type'          => Controls_Manager::NUMBER,
				'default'       => 6,
				'step'          => 1,
				'min'           => 1,
				'max'           => '',
				'label_block'   => true,
			]
		);

		$this->add_control(
			'show',
			[
				'label'         => esc_html__( 'Show', 'restaurantpro' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''         => esc_html__( 'All products', 'restaurantpro' ),
					'featured' => esc_html__( 'Featured products', 'restaurantpro' ),
					'onsale'   => esc_html__( 'On-sale products', 'restaurantpro' ),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'         => esc_html__( 'Order By', 'restaurantpro' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => 'date',
				'options'       => [
					'date'  => __( 'Date', 'restaurantpro' ),
					'price' => __( 'Price', 'restaurantpro' ),
					'rand'  => __( 'Random', 'restaurantpro' ),
					'sales' => __( 'Sales', 'restaurantpro' ),
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'         => esc_html__( 'Order', 'restaurantpro' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => 'desc',
				'options'       => [
					'desc'      => esc_html__( 'DESC', 'restaurantpro' ),
					'asc'       => esc_html__( 'ASC', 'restaurantpro' ),
				],
			]
		);

		$this->add_control(
			'include_categories',
			[
				'label' 		=> __( 'Include Categories', 'restaurantpro' ),
				'description' 	=> __( 'Enter the categories slugs seperated by a "comma"', 'restaurantpro' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'include_tags',
			[
				'label'         => esc_html__( 'Include Tags', 'restaurantpro' ),
				'description'   => esc_html__( 'Enter the tags slugs seperated by a "comma"', 'restaurantpro' ),
				'type'          => Controls_Manager::TEXT,
				'label_block'   => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'menu_style',
			[
				'label'         => esc_html__( 'Menu Style', 'restaurantpro' ),
				'tab'           => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'columns',
			[
				'label'         => esc_html__( 'Columns', 'restaurantpro' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => 'columns-3',
				'options'       => [
					'columns-2' => esc_html__( 'Two Columns', 'restaurantpro' ),
					'columns-3' => esc_html__( 'Three Columns', 'restaurantpro' ),
					'columns-4' => esc_html__( 'Four Columns', 'restaurantpro' ),
				],
			]
		);

		$this->add_control(
			'image',
			[
				'label'         => esc_html__( 'Image', 'restaurantpro' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''         => esc_html__( 'Default', 'restaurantpro' ),
					'no-image' => esc_html__( 'No Image', 'restaurantpro' ),
					'no-image' => esc_html__( 'No Image', 'restaurantpro' ),
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		// Vars
		$count     = $settings['count'];
		$show      = $settings['show'];
		$orderby   = $settings['orderby'];
		$order     = $settings['order'];
		$include   = $settings['include_categories'];
		$tags      = $settings['include_tags'];
		$columns   = $settings['columns'];
		$image     = $settings['image'];
		$product_visibility_term_ids = wc_get_product_visibility_term_ids();

		$query_args = array(
			'posts_per_page' => $count,
			'post_status'    => 'publish',
			'post_type'      => 'product',
			'no_found_rows'  => 1,
			'order'          => $order,
			'meta_query'     => array(),
			'tax_query'      => array(
				'relation' => 'AND',
			),
		);

		// Include category
		if ( ! empty( $include ) ) {

			// Sanitize category and convert to array
			$include = str_replace( ', ', ',', $include );
			$include = explode( ',', $include );

			// Add to query arg
			$query_args['tax_query'][] = array(
				'taxonomy' => 'product_cat',
				'field'    => 'slug',
				'terms'    => $include,
				'operator' => 'IN',
			);

		}

		// Include tag
		if ( ! empty( $tags ) ) {

			// Sanitize category and convert to array
			$tags = str_replace( ', ', ',', $tags );
			$tags = explode( ',', $tags );

			// Add to query arg
			$query_args['tax_query'][] = array(
				'taxonomy' => 'product_tag',
				'field'    => 'slug',
				'terms'    => $tags,
				'operator' => 'IN',
			);

		}

		switch ( $show ) {
			case 'featured':
				$query_args['tax_query'][] = array(
					'taxonomy' => 'product_visibility',
					'field'    => 'term_taxonomy_id',
					'terms'    => $product_visibility_term_ids['featured'],
				);
				break;
			case 'onsale':
				$product_ids_on_sale    = wc_get_product_ids_on_sale();
				$product_ids_on_sale[]  = 0;
				$query_args['post__in'] = $product_ids_on_sale;
				break;
		}

		switch ( $orderby ) {
			case 'price':
				$query_args['meta_key'] = '_price'; // WPCS: slow query ok.
				$query_args['orderby']  = 'meta_value_num';
				break;
			case 'rand':
				$query_args['orderby'] = 'rand';
				break;
			case 'sales':
				$query_args['meta_key'] = 'total_sales'; // WPCS: slow query ok.
				$query_args['orderby']  = 'meta_value_num';
				break;
			default:
				$query_args['orderby'] = 'date';
		}

		// Build the WordPress query
		$product = new \WP_Query( $query_args );

		// Output posts
		if ( $product->have_posts() ) :

			// Classes
			$wrap_classes = array( 'products-wrapper', 'woocommerce' );
			$wrap_classes[] = $columns;
			$wrap_classes[] = $image;
			$wrap_classes = implode( ' ', $wrap_classes );

			$ul_classes   = array( 'products' );
			$ul_classes[] = $columns;
			$ul_classes = implode( ' ', $ul_classes );
			?>

			<div class="<?php echo esc_attr( $wrap_classes ); ?>">
				<ul class="<?php echo esc_attr( $ul_classes ); ?>">

				<?php

				// Start loop
				while ( $product->have_posts() ) : $product->the_post(); ?>

					<?php wc_get_template_part( 'content', 'product' ); ?>

				<?php
				// End entry loop
				endwhile; ?>

				</ul>
			</div><!-- .products-wrapper -->

			<?php
			// Reset the post data to prevent conflicts with WP globals
			wp_reset_postdata();

		else : ?>

			<?php get_template_part( 'partials/content/content', 'none' ); ?>

		<?php endif; ?>

	<?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new RestaurantPro_Widget_Menu() );
